import { CommonModule } from '@angular/common';
import { Injectable, NgModule, Optional, SkipSelf } from '@angular/core';
import { Headers, Http } from '@angular/http';
import 'rxjs/add/operator/toPromise';

class SharepointListsWebService {
    /**
     * @param {?} http
     */
    constructor(http$$1) {
        this.http = http$$1;
        this.serviceUrl = '_vti_bin/Lists.asmx';
        this.xmlPayloadWrapperStart = `<?xml version="1.0" encoding="utf-8"?>
<soap12:Envelope xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:soap12="http://www.w3.org/2003/05/soap-envelope">
  <soap12:Body>`;
        this.xmlPayloadWrapperEnd = '</soap12:Body></soap12:Envelope>';
        this.getListItemsPayload = `
    <GetListItems xmlns="http://schemas.microsoft.com/sharepoint/soap/">
      <listName>listNamePayLoad</listName>
      <viewName>viewNamePayLoad</viewName>
      <query>queryPayload</query>
      <viewFields>viewFieldsPayload</viewFields>
      <rowLimit>rowLimitPayload</rowLimit>
      <QueryOptions>queryOptionsPayload</QueryOptions>
    </GetListItems>`;
        this.updateListItemsPayload = `<UpdateListItems xmlns="http://schemas.microsoft.com/sharepoint/soap/"><listName>listNamePayLoad</listName><updates>updatesPayLoad</updates></UpdateListItems>`;
        this.headers = new Headers({
            'Content-Type': 'application/soap+xml; charset=utf-8',
        });
    }
    /**
     * @param {?} ctor
     * @param {?} filterQuery
     * @param {?} camlQuery
     * @param {?} orderByField
     * @return {?}
     */
    getListItems(ctor, filterQuery, camlQuery, orderByField) {
        let /** @type {?} */ dummyInstance = new ctor();
        let /** @type {?} */ currentPayload = this.xmlPayloadWrapperStart + this.getListItemsPayload + this.xmlPayloadWrapperEnd;
        currentPayload = currentPayload.replace("listNamePayLoad", dummyInstance.getListName());
        currentPayload = currentPayload.replace("viewNamePayLoad", "");
        if (filterQuery || camlQuery) {
            if (filterQuery) {
                let /** @type {?} */ internalCamlQuery = "<Query><Where><Eq><FieldRef Name='FieldName' /><Value Type='Text'>ValueName</Value></Eq></Where></Query>";
                internalCamlQuery = internalCamlQuery.replace("FieldName", filterQuery[0]);
                internalCamlQuery = internalCamlQuery.replace("ValueName", filterQuery[1]);
                currentPayload = currentPayload.replace("queryPayload", internalCamlQuery);
            }
            else {
                currentPayload = currentPayload.replace("queryPayload", camlQuery);
            }
        }
        else {
            currentPayload = currentPayload.replace("queryPayload", "");
        }
        currentPayload = currentPayload.replace("viewFieldsPayload", "");
        currentPayload = currentPayload.replace("rowLimitPayload", "");
        currentPayload = currentPayload.replace("queryOptionsPayload", "");
        return this.http.post(dummyInstance.getSiteUrl() + this.serviceUrl, currentPayload, { headers: this.headers, })
            .toPromise()
            .then(function (res) {
            let /** @type {?} */ filledResponse = [];
            $(res.text()).find("z\\:row, row").each(function (index) {
                filledResponse.push(new ctor($(this)[0].attributes));
            });
            return filledResponse;
        })
            .catch(this.handleError);
    }
    /**
     * @param {?} itemToUpdate
     * @param {?} newValue
     * @return {?}
     */
    updateListItem(itemToUpdate, newValue) {
        let /** @type {?} */ currentPayload = this.xmlPayloadWrapperStart + this.updateListItemsPayload + this.xmlPayloadWrapperEnd;
        currentPayload = currentPayload.replace("listNamePayLoad", itemToUpdate.getListName());
        currentPayload = currentPayload.replace("updatesPayLoad", `<Batch OnError="Continue"><Method ID="1" Cmd="Update"><Field Name="ID">` + itemToUpdate.ID + `</Field><Field Name="` + itemToUpdate.getFieldToUpdate() + `">` + newValue + `</Field></Method></Batch>`);
        return this.http.post(itemToUpdate.getSiteUrl() + this.serviceUrl, currentPayload, { headers: this.headers, })
            .toPromise()
            .then(() => null)
            .catch(this.handleError);
    }
    /**
     * @param {?} error
     * @return {?}
     */
    handleError(error) {
        console.error('An error occurred', error); // for demo purposes only
        return Promise.reject(error.message || error);
    }
    /**
     * @param {?} itemToUpdate
     * @param {?} keyValuePairs
     * @return {?}
     */
    addOrUpdateListItem(itemToUpdate, keyValuePairs) {
        let /** @type {?} */ currentPayload = this.xmlPayloadWrapperStart + this.updateListItemsPayload + this.xmlPayloadWrapperEnd;
        let /** @type {?} */ perColumnString = `<Field Name="fieldName">fieldValue</Field>`;
        let /** @type {?} */ allColumnsToUpdate = '';
        let /** @type {?} */ command = "New";
        //if there is an existing 'ID' property with a value, then this is not new but update.
        for (let /** @type {?} */ i = 0; i < keyValuePairs.length; i++) {
            if (keyValuePairs[i][0] == "ID" && keyValuePairs[i][1]) {
                command = "Update";
                break;
            }
        }
        keyValuePairs.forEach(entry => allColumnsToUpdate = allColumnsToUpdate + perColumnString.replace("fieldName", entry[0]).replace("fieldValue", entry[1]));
        currentPayload = currentPayload.replace("listNamePayLoad", itemToUpdate.getListName());
        currentPayload = currentPayload.replace("updatesPayLoad", `<Batch OnError="Continue"><Method ID="1" Cmd="` + command + `">` + allColumnsToUpdate + `</Method></Batch>`);
        return this.http.post(itemToUpdate.getSiteUrl() + this.serviceUrl, currentPayload, { headers: this.headers, })
            .toPromise()
            .then(function (res) {
            return +$(res.text()).find("z\\:row:first, row:first").attr("ows_ID");
        })
            .catch(this.handleError);
    }
}
SharepointListsWebService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
SharepointListsWebService.ctorParameters = () => [
    { type: Http, },
];

/**
 * Dummy version of an authenticated user service
 */
class UrlService {
    /**
     * @return {?}
     */
    navigateToDefaultSource() {
        if (GetUrlKeyValue('Source', false, window.location.href)) {
            window.location.href = GetUrlKeyValue('Source', false, window.location.href);
        }
        else {
            window.location.href = _spPageContextInfo.webServerRelativeUrl;
        }
    }
    /**
     * @return {?}
     */
    getItemId() {
        try {
            return GetUrlKeyValue('ID', false, window.location.href);
        }
        catch (x) {
            return '';
        }
    }
}
UrlService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
UrlService.ctorParameters = () => [];

class SharePointUserProfile {
}

class SharePointUserProfileWebService {
    /**
     * @param {?} http
     */
    constructor(http$$1) {
        this.http = http$$1;
        this.serviceUrl = '/_vti_bin/UserProfileService.asmx';
        this.xmlPayloadWrapperStart = `<?xml version="1.0" encoding="utf-8"?>
<soap12:Envelope xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:soap12="http://www.w3.org/2003/05/soap-envelope">
  <soap12:Body>`;
        this.xmlPayloadWrapperEnd = '</soap12:Body></soap12:Envelope>';
        this.getUserProfileByNamePayload = `
    <GetUserProfileByName xmlns="http://microsoft.com/webservices/SharePointPortalServer/UserProfileService">
      <AccountName>accountNameString</AccountName>
    </GetUserProfileByName>`;
        this.headers = new Headers({
            'Content-Type': 'application/soap+xml; charset=utf-8',
        });
    }
    /**
     * @param {?=} accountName
     * @return {?}
     */
    getUserProfileByName(accountName) {
        let /** @type {?} */ currentPayload = this.xmlPayloadWrapperStart + this.getUserProfileByNamePayload + this.xmlPayloadWrapperEnd;
        if (accountName) {
            currentPayload = currentPayload.replace("accountNameString", accountName);
        }
        else {
            currentPayload = currentPayload.replace("accountNameString", "");
        }
        return this.http.post(this.serviceUrl, currentPayload, { headers: this.headers, })
            .toPromise()
            .then(function (res) {
            let /** @type {?} */ filledResponse = new SharePointUserProfile();
            let /** @type {?} */ jQueryValue = $(res.text()).find("PropertyData:has(name:contains('WorkEmail'))").find('value').text();
            if (jQueryValue) {
                filledResponse.workEmail = jQueryValue;
            }
            jQueryValue = $(res.text()).find("PropertyData:has(name:contains('WorkPhone'))").find('value').text();
            if (jQueryValue) {
                filledResponse.workPhone = jQueryValue;
            }
            $(res.text()).find("z\\:row, row").each(function (index) {
                
                //$(this)[0].attributes)
                //do some fancy jquery coding here.
            });
            return filledResponse;
        })
            .catch(this.handleError);
    }
    /**
     * @param {?} error
     * @return {?}
     */
    handleError(error) {
        console.error('An error occurred', error); // for demo purposes only
        return Promise.reject(error.message || error);
    }
}
/* return this.http.post(dummyInstance.getSiteUrl()+this.serviceUrl, currentPayload,{headers:this.headers,})
.toPromise()
.then(function(res)
    {
        let filledResponse:SharepointListItem[] = [];
        $(res.text()).find("z\\:row, row").each(function( index:any ) {
            filledResponse.push(new ctor($(this)[0].attributes));
        });
        return filledResponse;
})
.catch(this.handleError);
}



.then(function (res){
    return +$(res.text()).find("z\\:row:first, row:first").attr("ows_ID");
})
.catch(this.handleError);
} */
SharePointUserProfileWebService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
SharePointUserProfileWebService.ctorParameters = () => [
    { type: Http, },
];

class NgTaxServices {
    /**
     * @param {?} parentModule
     */
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('NgTaxServices / NgTaxSharePointWebServicesModule is already loaded. Import it in the AppModule only');
        }
    }
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: NgTaxServices,
            providers: [SharepointListsWebService, UrlService, SharePointUserProfileWebService]
        };
    }
}
NgTaxServices.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [],
                exports: []
            },] },
];
/**
 * @nocollapse
 */
NgTaxServices.ctorParameters = () => [
    { type: NgTaxServices, decorators: [{ type: Optional }, { type: SkipSelf },] },
];

/**
 * @abstract
 */
class SharepointListItem {
    /**
     * @param {?=} rawResponse
     */
    constructor(rawResponse) {
        if (rawResponse) {
            this.ID = +this.findString('ows_id', rawResponse);
            for (let x = 0; x < this.getItemProperties().length; x++) {
                this[this.getItemProperties()[x]] = this.findString('ows_' + this.getItemProperties()[x].toLowerCase(), rawResponse);
            }
        }
    }
    /**
     * @param {?} searchTerm
     * @param {?} myArray
     * @return {?}
     */
    findString(searchTerm, myArray) {
        for (let /** @type {?} */ x = 0; x < myArray.length; x++) {
            if (myArray[x].name == searchTerm) {
                return myArray[x].value;
            }
        }
        return '';
    }
    /**
     * @abstract
     * @return {?}
     */
    getSiteUrl() { }
    /**
     * @abstract
     * @return {?}
     */
    getListName() { }
    /**
     * @abstract
     * @return {?}
     */
    getFieldToUpdate() { }
    /**
     * @return {?}
     */
    getItemProperties() {
        return [];
    }
    /**
     * @param {?} aString
     * @return {?}
     */
    toBoolean(aString) {
        if (this[aString]) {
            this[aString] = this[aString] && this[aString] == "true";
        }
    }
    /**
     * @param {?} aString
     * @return {?}
     */
    toInteger(aString) {
        if (this[aString] && this[aString].includes(".")) {
            this[aString] = this[aString].split(".")[0];
        }
    }
}

class UserInfoListEntry extends SharepointListItem {
    /**
     * @param {?=} rawResponse
     */
    constructor(rawResponse) {
        super(rawResponse);
        
    }
    /**
     * @return {?}
     */
    getItemProperties() {
        return ["title", "jobTitle", "name", "email"];
    }
    /**
     * @return {?}
     */
    getSiteUrl() {
        return '/';
    }
    /**
     * @return {?}
     */
    getListName() {
        return 'User Information List';
    }
    /**
     * @return {?}
     */
    getFieldToUpdate() {
        return 'Not implemented';
    }
}

/**
 * Generated bundle index. Do not edit.
 */

export { NgTaxServices, SharepointListsWebService, UrlService, SharePointUserProfileWebService, SharepointListItem, SharePointUserProfile, UserInfoListEntry };
//# sourceMappingURL=ng-tax-share-point-web-services-module.js.map
